import java.awt.BorderLayout;
import java.awt.Dimension;

import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.JTextField;
import javax.swing.text.DefaultCaret;


/**
 * A Java application to serve as a reminder of how some of the basic GUI
 * elements are pieced together in Java.  This isn't meant to be pretty (I'll leave
 * it to you to make your project GUI pretty.); it's simply meant to demonstrate
 * several GUI elements. 
 * 
 * @author Tom Kelliher
 *
 */
public class GUI {
	
	public GUI() {
		// Construct the application's window.
		JFrame window = new JFrame("Simple GUI Demo");
		//window.setSize(800, 800);
		window.setLayout(new BorderLayout());
		
		// This panel will hold the label used to display an image and the buttons
		// used to change the displayed image and to close the window, shutting down
		// the application.  This is the standard way of displaying an image in a
		// Java application.  Java does not make it easy to resize an image.  To
		// compensate, picture's preferred size is set to the maximum width of the
		// images used and the maximum height of the images used.  Of course, it's
		// possible that these maximums could correspond to different images.
		// 
		// The images are stored in their own folder.
		
		JPanel panel = new JPanel();
		panel.setLayout(new BorderLayout());
		ImageIcon[] images = new ImageIcon[2];
		images[0] = new ImageIcon("Images/daemon.gif");
		images[1] = new ImageIcon("Images/linuxPenguin.jpeg");
		JLabel picture = new JLabel(images[0]);
		picture.setPreferredSize(new Dimension(425, 292));
		panel.add(picture, BorderLayout.CENTER);
		JButton button = new JButton("Change Image");
		button.addActionListener(new ButtonListener(picture, images));
		panel.add(button, BorderLayout.SOUTH);
		button = new JButton("Exit");
		button.addActionListener(e -> window.dispose());
		panel.add(button, BorderLayout.NORTH);
		window.add(panel, BorderLayout.NORTH);
		
		// This panel will hold the output display JTextArea object.
		
		JTextArea textArea = new JTextArea(10, 20);
		textArea.setEditable(false);
		JScrollPane display = new JScrollPane(textArea);
		JLabel label = new JLabel("Display");
		panel = new JPanel();
		panel.setLayout(new BorderLayout());
		panel.add(display, BorderLayout.CENTER);
		panel.add(label, BorderLayout.WEST);
		window.add(panel, BorderLayout.CENTER);
		
		// This Panel will hold one of the input JTextField objects.
		
		panel = new JPanel();
		panel.setLayout(new BorderLayout());
		label = new JLabel("Input 1");
		panel.add(label, BorderLayout.WEST);
		JTextField input = new JTextField(15);
		// Creating il this way so that it can be reused in the next panel.
		InputListener il = new InputListener(textArea);
		input.addActionListener(il);
		panel.add(input, BorderLayout.CENTER);
		window.add(panel, BorderLayout.SOUTH);
		
		// This panel will hold the other input JTextField object.
		
		panel = new JPanel();
		panel.setLayout(new BorderLayout());
		label = new JLabel("Input 2");
		panel.add(label, BorderLayout.WEST);
		input = new JTextField(10);
		// Reuse il.
		input.addActionListener(il);
		panel.add(input, BorderLayout.CENTER);
		window.add(panel, BorderLayout.WEST);
		
		// Finish preparing the window and display it.
		window.pack();
		window.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		window.setVisible(true);
	}

	public static void main(String[] args) {
		new GUI();
	}

}
